==> kubernetes-model-1.0.60-sources.jar: io/fabric8/openshift/api/model/TemplateBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class TemplateBuilder extends TemplateFluentImpl<TemplateBuilder> implements VisitableBuilder<Template,TemplateBuilder>{

    TemplateFluent<?> fluent;
    Boolean validationEnabled;

    public TemplateBuilder(){
            this(true);
    }
    public TemplateBuilder(Boolean validationEnabled){
            this(new Template(), validationEnabled);
    }
    public TemplateBuilder(TemplateFluent<?> fluent){
            this(fluent, true);
    }
    public TemplateBuilder(TemplateFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new Template(), validationEnabled);
    }
    public TemplateBuilder(TemplateFluent<?> fluent,Template instance){
            this(fluent, instance, true);
    }
    public TemplateBuilder(TemplateFluent<?> fluent,Template instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withKind(instance.getKind()); 
            fluent.withLabels(instance.getLabels()); 
            fluent.withMetadata(instance.getMetadata()); 
            fluent.withObjects(instance.getObjects()); 
            fluent.withParameters(instance.getParameters()); 
            this.validationEnabled = validationEnabled; 
    }
    public TemplateBuilder(Template instance){
            this(instance,true);
    }
    public TemplateBuilder(Template instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withLabels(instance.getLabels()); 
            this.withMetadata(instance.getMetadata()); 
            this.withObjects(instance.getObjects()); 
            this.withParameters(instance.getParameters()); 
            this.validationEnabled = validationEnabled; 
    }

    public Template build(){
            Template buildable = new Template(fluent.getApiVersion(),fluent.getKind(),fluent.getLabels(),fluent.getMetadata(),fluent.getObjects(),fluent.getParameters());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            TemplateBuilder that = (TemplateBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/openshift/api/model/TemplateBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class TemplateBuilder extends TemplateFluentImpl<TemplateBuilder> implements VisitableBuilder<Template,TemplateBuilder>{

    TemplateFluent<?> fluent;
    Boolean validationEnabled;

    public TemplateBuilder(){
            this(true);
    }
    public TemplateBuilder(Boolean validationEnabled){
            this(new Template(), validationEnabled);
    }
    public TemplateBuilder(TemplateFluent<?> fluent){
            this(fluent, true);
    }
    public TemplateBuilder(TemplateFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new Template(), validationEnabled);
    }
    public TemplateBuilder(TemplateFluent<?> fluent,Template instance){
            this(fluent, instance, true);
    }
    public TemplateBuilder(TemplateFluent<?> fluent,Template instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withKind(instance.getKind()); 
            fluent.withLabels(instance.getLabels()); 
            fluent.withMetadata(instance.getMetadata()); 
            fluent.withObjects(instance.getObjects()); 
            fluent.withParameters(instance.getParameters()); 
            this.validationEnabled = validationEnabled; 
    }
    public TemplateBuilder(Template instance){
            this(instance,true);
    }
    public TemplateBuilder(Template instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withLabels(instance.getLabels()); 
            this.withMetadata(instance.getMetadata()); 
            this.withObjects(instance.getObjects()); 
            this.withParameters(instance.getParameters()); 
            this.validationEnabled = validationEnabled; 
    }

    public Template build(){
            Template buildable = new Template(fluent.getApiVersion(),fluent.getKind(),fluent.getLabels(),fluent.getMetadata(),fluent.getObjects(),fluent.getParameters());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            TemplateBuilder that = (TemplateBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
